@@ -40,24 +40,29 @@ open browser  https://www.google.com  chrome
 '''
 
 from __future__ import print_function
-from robot.errors import HandlerExecutionFailed
-from robot.libraries.BuiltIn import BuiltIn
-from robot.api import logger
-from robot.variables import is_var
+
 import cmd
 import os
 import re
+import sys
+
+from robot.api import logger
+from robot.errors import HandlerExecutionFailed
+from robot.libraries.BuiltIn import BuiltIn
+from robot.variables import is_var
+
 try:
     import readline
 except ImportError:
     # this will fail on IronPython
     pass
-import sys
 
-__version__ = '0.8'
+__version__ = '0.8.2'
 
 KEYWORD_SEP = re.compile('  +|\t')
 
+COMMAND_LINE_ENCODING = sys.stdout.encoding or 'utf-8'
+
 
 class BaseCmd(cmd.Cmd):
 
@@ -136,7 +141,11 @@ class DebugCmd(BaseCmd):
         if not command:
             return
         try:
-            u_command = command.decode("utf-8")
+            u_command = ''
+            if sys.version_info > (3,):
+                u_command = command
+            else:
+                u_command = command.decode(COMMAND_LINE_ENCODING)
             keyword = KEYWORD_SEP.split(u_command)
             variable_name = keyword[0].rstrip('= ')
 
@@ -237,5 +246,6 @@ REPL
         os.unlink(source.name)
     sys.exit(rc)
 
+
 if __name__ == '__main__':
     shell()
